tokenizer\_tools.evaluator package
==================================

Subpackages
-----------

.. toctree::

   tokenizer_tools.evaluator.token

Submodules
----------

tokenizer\_tools.evaluator.offset\_evaluator module
---------------------------------------------------

.. automodule:: tokenizer_tools.evaluator.offset_evaluator
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.evaluator.tag\_level\_evaluator module
-------------------------------------------------------

.. automodule:: tokenizer_tools.evaluator.tag_level_evaluator
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tokenizer_tools.evaluator
   :members:
   :undoc-members:
   :show-inheritance:
